@@ -8,18 +8,20 @@
 import logging
 from logging import NullHandler
 
+from .nem_reader import NEMFile, read_nem_file
+from .outputs import (
+    nmis_in_file,
+    output_as_csv,
+    output_as_daily_csv,
+    output_as_data_frames,
+    output_as_sqlite,
+)
 from .version import __version__
-from .nem_reader import read_nem_file, parse_nem_file
-from .outputs import output_as_csv
-from .outputs import output_as_daily_csv
-from .outputs import nmis_in_file
-from .outputs import output_as_data_frames
-from .outputs import output_as_sqlite
 
 __all__ = [
     "__version__",
+    "NEMFile",
     "read_nem_file",
-    "parse_nem_file",
     "nmis_in_file",
     "output_as_csv",
     "output_as_daily_csv",
