@@ -62,7 +62,7 @@ def output_csv(
 ):
     """Output NEM file to transposed CSV.
 
-    NEMFILE is the name of the file to parse.
+    nemfile is the name of the file to parse.
     """
     if verbose:
         log_level = "DEBUG"
@@ -87,7 +87,7 @@ def output_csv_daily(
 ):
     """Output NEM file to transposed CSV.
 
-    NEMFILE is the name of the file to parse.
+    nemfile is the name of the file to parse.
     """
     if verbose:
         log_level = "DEBUG"
@@ -113,7 +113,7 @@ def output_sqlite(
 ):
     """Output NEM file to transposed CSV.
 
-    NEMFILE is the name of the file to parse.
+    nemfile is the name of the file to parse.
     """
     if verbose:
         log_level = "DEBUG"
@@ -132,4 +132,4 @@ def output_sqlite(
             output_as_sqlite(fp, output_dir=outdir, make_fivemins=five_min)
         except Exception:
             typer.echo(f"Not a valid nem file: {fp}")
-    typer.echo(f"Finished exporting to DB.")
+    typer.echo("Finished exporting to DB.")
